var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
import React from 'react';
import styled from 'styled-components';
import { PercentageProgressBar } from "../../components/elements";
import { isOwner, isParticipantInReview, isReviewer, isReviewRequested, allReviewersAreParticipants, getReviewerIds, getParticipantIds, } from '../utils';
var NewStatus = styled.span.withConfig({ displayName: "NewStatus", componentId: "sc-2cp94o" })(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  color: ", ";\n  font-weight: 700;\n"], ["\n  color: ", ";\n  font-weight: 700;\n"])), function (_a) {
    var theme = _a.theme;
    return theme.colors.primary.default;
});
var IndicatorOptions;
(function (IndicatorOptions) {
    IndicatorOptions["EYE"] = "eye";
    IndicatorOptions["HANDSHAKE"] = "handshake";
})(IndicatorOptions || (IndicatorOptions = {}));
function withoutOwner(_a, smeExpert) {
    var conversionOwnerId = _a.conversionOwnerId, teachingOwnerId = _a.teachingOwnerId;
    return smeExpert ? !teachingOwnerId : !conversionOwnerId;
}
export function getIndicator(_a, smeExpert, currentUserId, reviewerIds) {
    var handedOver = _a.handedOver, teachingReviewerIds = _a.teachingReviewerIds, conversionReviewerIds = _a.conversionReviewerIds, conversionOwnerId = _a.conversionOwnerId, teachingOwnerId = _a.teachingOwnerId;
    if (smeExpert && handedOver) {
        return IndicatorOptions.HANDSHAKE;
    }
    var owner = isOwner(smeExpert, currentUserId, {
        teachingOwnerId: teachingOwnerId,
        conversionOwnerId: conversionOwnerId,
    });
    var reviewRequested = isReviewRequested(reviewerIds);
    var reviewer = isReviewer(currentUserId, reviewerIds);
    if ((owner && reviewRequested) || reviewer) {
        return IndicatorOptions.EYE;
    }
}
function shouldShowTick(_a, smeExpert, currentUserId, reviewerIds, participantIds) {
    var commentsCount = _a.commentsCount, handedOver = _a.handedOver, teachingOwnerId = _a.teachingOwnerId, conversionOwnerId = _a.conversionOwnerId;
    var owner = isOwner(smeExpert, currentUserId, {
        teachingOwnerId: teachingOwnerId,
        conversionOwnerId: conversionOwnerId,
    });
    var allReviewersCompleted = allReviewersAreParticipants(reviewerIds, participantIds);
    var reviewer = isReviewer(currentUserId, reviewerIds);
    var participant = isParticipantInReview(currentUserId, participantIds);
    return (Boolean(handedOver && smeExpert) ||
        Boolean(owner && allReviewersCompleted) ||
        Boolean(reviewer && participant));
}
function getPopoverText(_a, smeExpert, currentUserId, reviewerIds, participantIds) {
    var teachingOwnerId = _a.teachingOwnerId, handedOver = _a.handedOver, conversionOwnerId = _a.conversionOwnerId;
    if (smeExpert && handedOver) {
        return 'Handover done';
    }
    var owner = isOwner(smeExpert, currentUserId, {
        teachingOwnerId: teachingOwnerId,
        conversionOwnerId: conversionOwnerId,
    });
    if (owner) {
        var reviewRequested = isReviewRequested(reviewerIds);
        if (reviewRequested) {
            var allReviewersCompleted = allReviewersAreParticipants(reviewerIds, participantIds);
            if (allReviewersCompleted) {
                return 'Review completed';
            }
            return 'Review requested';
        }
    }
    else {
        var reviewer = isReviewer(currentUserId, reviewerIds);
        if (reviewer) {
            var participant = isParticipantInReview(currentUserId, participantIds);
            if (participant) {
                return 'Review delivered';
            }
            return 'Review required';
        }
    }
}
function getProgress(_a, smeExpert) {
    var _b = _a.teachingRoomsCompleted, teachingRoomsCompleted = _b === void 0 ? 0 : _b, _c = _a.teachingRooms, teachingRooms = _c === void 0 ? 0 : _c, _d = _a.teachingStepsDeployed, teachingStepsDeployed = _d === void 0 ? 0 : _d, _e = _a.teachingSteps, teachingSteps = _e === void 0 ? 0 : _e;
    return smeExpert
        ? prepareProgressValue(teachingRoomsCompleted, teachingRooms)
        : prepareProgressValue(teachingStepsDeployed, teachingSteps);
}
function prepareProgressValue(value, total) {
    return Math.round((Number(value) / Number(total)) * 100) || 0;
}
// TODO smeExpert => role || sme
export var SessionProgressBar = function (_a) {
    var session = _a.session, _b = _a.smeExpert, smeExpert = _b === void 0 ? false : _b, currentUserId = _a.currentUserId;
    var reviewerIds = getReviewerIds(smeExpert, session);
    var participantIds = getParticipantIds(smeExpert, session);
    var progress = getProgress(session, smeExpert);
    var popover = getPopoverText(session, smeExpert, currentUserId, reviewerIds, participantIds);
    var indicator = getIndicator(session, smeExpert, currentUserId, reviewerIds);
    var withTick = shouldShowTick(session, smeExpert, currentUserId, reviewerIds, participantIds);
    var noOwner = withoutOwner(session, smeExpert);
    if (noOwner && progress === 0) {
        return React.createElement(NewStatus, null, "NEW");
    }
    return (React.createElement(PercentageProgressBar, { indicator: indicator, progress: progress, popover: popover, withTick: withTick }));
};
var templateObject_1;
